<?php
namespace KudosQodef\Modules\Shortcodes\NumberedProcess;

use KudosQodef\Modules\Shortcodes\Lib\ShortcodeInterface;

/**
 * NumberedProcess
 * @package KudosQodef\Modules\Shortcodes\NumberedProcess
 */
class NumberedProcess implements ShortcodeInterface {
    /**
     * @var string
     */
    private $base;

    /**
     *
     */
    public function __construct() {
        $this->base = 'qodef_numbered_process';

        add_action('vc_before_init', array($this, 'vcMap'));
    }

    /**
     * @return string
     */
    public function getBase() {
        return $this->base;
    }

    /**
     *
     */

	public function vcMap() {
		vc_map(array(
			'name'                      => esc_html__('Select Numbered Process', 'kudos'),
			'base'                      => $this->base,
			'icon'                      => 'icon-wpb-numbered-process extended-custom-icon',
			'category'                  => 'by SELECT',
			'allowed_container_element' => 'vc_row',
			'params'                    => array_merge(
				array(
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__('Type', 'kudos'),
						'param_name' => 'type',
						'value'      => array(
							''   => '',
							esc_html__('Small Number', 'kudos') => 'small_number',
							esc_html__('Big Number', 'kudos') => 'big_number',
						),
						'admin_label' => true
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__('Number', 'kudos'),
						'param_name'  => 'number',
						'value'       => '',
						'admin_label' => true
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__('Number Font Size', 'kudos'),
						'param_name'  => 'number_size',
						'description' => esc_html__('Number font size(px)', 'kudos'),
						'value'       => '',
						'dependency' => array('element' => 'number', 'not_empty' => true)
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__('Title', 'kudos'),
						'param_name'  => 'title',
						'value'       => '',
						'admin_label' => true
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__('Title Tag', 'kudos'),
						'param_name' => 'title_tag',
						'value'      => array(
							''   => '',
							esc_html__('h2', 'kudos') => 'h2',
							esc_html__('h3', 'kudos') => 'h3',
							esc_html__('h4', 'kudos') => 'h4',
							esc_html__('h5', 'kudos') => 'h5',
							esc_html__('h6', 'kudos') => 'h6',
						),
						'dependency' => array('element' => 'title', 'not_empty' => true)
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__('Subtitle', 'kudos'),
						'param_name'  => 'subtitle',
						'value'       => '',
						'admin_label' => true
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => esc_html__('Subtitle Color', 'kudos'),
						'param_name'  => 'subtitle_color',
						'dependency'  => array('element' => 'subtitle', 'not_empty' => true),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__('Separator', 'kudos'),
						'param_name' => 'separator',
						'value'      => array(
							''   => '',
							esc_html__('No', 'kudos') => 'no',
							esc_html__('Yes', 'kudos') => 'yes'
						),
						'group'      => esc_html__('Layout Options', 'kudos')
					),
					array(
						'type'       => 'textarea',
						'heading'    => esc_html__('Text', 'kudos'),
						'param_name' => 'text'
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__('Link', 'kudos'),
						'param_name'  => 'link',
						'value'       => '',
						'admin_label' => true
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__('Link Text', 'kudos'),
						'param_name' => 'link_text',
						'dependency' => array('element' => 'link', 'not_empty' => true)
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__('Target', 'kudos'),
						'param_name' => 'target',
						'value'      => array(
							''      => '',
							esc_html__('Self', 'kudos')  => '_self',
							esc_html__('Blank', 'kudos') => '_blank'
						),
						'dependency' => array('element' => 'link', 'not_empty' => true),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__('Text Alignment', 'kudos'),
						'param_name' => 'text_alignment',
						'value'      => array(
							''        => '',
							esc_html__('Center', 'kudos')  => 'center',
							esc_html__('Left', 'kudos')    => 'left',
							esc_html__('Right', 'kudos')   => 'right'
						),
						'group'      => esc_html__('Layout Options', 'kudos')
					),
				)
			)
		));
	}

	/**
	 * @param array $atts
	 * @param null $content
	 *
	 * @return string
	 */
	public function render($atts, $content = null) {
		$default_atts = array(
			'type'					  	  => 'small_number',
			'number'					  => '',
			'number_size'				  => '',
			'title'                       => '',
			'title_tag'                   => 'h3',
			'subtitle'					  => '',
			'subtitle_color'			  => '',
			'separator'   				  => 'yes',
			'text'                        => '',
			'text_color'                  => '',
			'link'                        => '',
			'link_text'                   => 'Read More',
			'target'                      => '_self',
			'text_alignment'              => 'left'
		);

		$default_atts = array_merge($default_atts, kudos_qodef_icon_collections()->getShortcodeParams());
		$params       = shortcode_atts($default_atts, $atts);

		$params['text_styles']     		= $this->getTextStyles($params);
		$params['holder_classes']     	= $this->getHolderClasses($params);
		$params['subtitle_color']     	= $this->getSubtitleColor($params);
		$params['number_size']			= $this->getNumberSize($params);

		return kudos_qodef_get_shortcode_module_template_part('templates/numbered-process', 'numbered-process', '', $params);
	}

	/**
	 * Returns array of holder classes
	 *
	 * @param $params
	 *
	 * @return array
	 */
	private function getHolderClasses($params) {
		$classes = array('qodef-numbered-process-holder', 'clearfix');

		if(!empty($params['type'])) {
			switch($params['type']) {
				case 'small_number':
					$classes[] = 'qodef-numbered-process-small-number';
					break;
				case 'big_number':
					$classes[] = 'qodef-numbered-process-big-number';
					break;
				default:
					break;
			}
		}

		if(!empty($params['text_alignment'])) {
			switch($params['text_alignment']) {
				case 'left':
					$classes[] = 'qodef-numbered-process-text-left';
					break;
				case 'center':
					$classes[] = 'qodef-numbered-process-text-center';
					break;
				case 'right':
					$classes[] = 'qodef-numbered-process-text-right';
					break;
				default:
					break;
			}
		}

		return $classes;
	}

	private function getTextStyles($params) {
		$styles = array();

		if(!empty($params['text_color'])) {
			$styles[] = 'color: '.$params['text_color'];
		}

		return $styles;
	}

	private function getSubtitleColor($params) {
		$styles = array();

		if(!empty($params['subtitle_color'])) {
			$styles[] = 'color: ' . $params['subtitle_color'];
		}

		return $styles;
	}

	private function getNumberSize($params) {
		$styles = array();

		if(!empty($params['number_size'])) {
			$styles[] = 'font-size: ' . $params['number_size']. 'px';
		}

		return $styles;
	}

}